## What does this PR do?

## Type of change
- [ ] Bug fix
- [ ] New tool
- [ ] Documentation
- [ ] Other

## Checklist
- [ ] New tools have a docstring
- [ ] No `**kwargs` in tool function signatures
- [ ] Tested in MCP Inspector — tool appears with correct schema
- [ ] Return values are JSON-serialisable
